from . import read_image
from . import create_prompt
from . import handle_prompt 

def main_cli():
    print('\nTODO 1)\n')
    read_image()
    print('\nTODO 2)\n')
    create_prompt()
    print('\nTODO 3)\n')
    handle_prompt()
    print()
